.. _index:

=============
Documentation
=============

This product allows you to serve files and browse directories from the
local file system (or network shares on Windows platforms). It also
allows you to upload files to the file system trough a browser or WebDAV.


Narrative documentation
-----------------------
Narrative documentation explaining how to use :mod:`Products.LocalFS`.

.. toctree::
    :maxdepth: 2

    development
    usage
    changes


Indices and tables
------------------
* :ref:`genindex`
* :ref:`search`
* :ref:`glossary`

